# Simple Seller

## Description

This skill is used to sell data present in the shared state.

## Behaviours

* the behaviours are imported from the `fetchai/generic_seller` skill

## Handlers

* the handlers are imported from the `fetchai/generic_seller` skill

## Models

* the strategy model is extended from the `fetchai/generic_seller` skill and loads data from the shared state using the key `shared_state_key` specified in the skill config.
